@@ -1,6 +1,6 @@
 /*
  *   kmoon - a moon phase indicator
- *   Copyright (C) 1998  Stephan Kulow
+ *   Copyright (C) 1998,2000  Stephan Kulow
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -16,7 +16,10 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- */ 
+ */
+
+#ifndef KMOON
+#define KMOON
 
 #include <qwidget.h>
 #include <qimage.h>
@@ -30,29 +33,32 @@ class MoonWidget : public QWidget
 public:
     MoonWidget(QWidget *parent = 0, const char *name = 0);
     void calcStatus( time_t time );
+	void setAngle(int angle);
 
 protected:
     QImage loadMoon(int index);
-    int counter;
+    int counter, angle;
     QPopupMenu *popup;
     QPixmap pixmap;
     int old_counter;
-    int old_w, old_h;
+    int old_w, old_h, old_a;
     QString tooltip;
 
 protected slots:
-   
+
     void timerEvent( QTimerEvent *e);
     void showAbout();
-    void reactOn(int);
-    
+	void settings();
+
 protected:
     void renderGraphic();
     virtual void paintEvent( QPaintEvent *e);
     virtual void resizeEvent( QResizeEvent *e);
     virtual void mousePressEvent( QMouseEvent *e);
 
-private: 
+private:
   int id_about;
   int id_quit;
 };
+
+#endif
