@@ -6,6 +6,8 @@
 
  ------------------------------------------------------------- */
 
+#include <stdlib.h>
+
 #include <qcheckbox.h>
 #include <qdialog.h>
 #include <qframe.h>
@@ -18,13 +20,13 @@
 #include <qpushbutton.h>
 #include <qspinbox.h>
 #include <qtooltip.h>
-#include <stdlib.h>
+#include <qfile.h>
 
 #include <kconfig.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kwm.h>
+#include <kwin.h>
 
 #include "toplevel.h"
 
@@ -69,10 +71,10 @@ TopLevel::TopLevel()
   teatime = (*times.at(num)).toInt();
 
   menu->insertSeparator();
-  menu->insertItem(i18n("&Start"), this, SLOT(start()));
+  menu->insertItem(SmallIcon("1rightarrow"), i18n("&Start"), this, SLOT(start()));
   menu->insertSeparator();
-  menu->insertItem(i18n("&Configure..."), this, SLOT(config()));
-  menu->insertItem(i18n("Quit"), kapp, SLOT(quit()));
+  menu->insertItem(SmallIcon("configure"), i18n("&Configure..."), this, SLOT(config()));
+  menu->insertItem(SmallIcon("exit"), i18n("Quit"), kapp, SLOT(quit()));
 
   beeping = config->readBoolEntry("Beep", true);
   popping = config->readBoolEntry("Popup", true);
@@ -114,17 +116,7 @@ void TopLevel::mousePressEvent(QMouseEvent *event)
         start();
   }
   else
-  {
-    menu->move(-1000,-1000);
-    menu->show();
-    menu->hide();
-    QRect g = KWM::geometry( this->winId() );
-    if ( g.x() > QApplication::desktop()->width()/2 &&
-      g.y()+menu->height() > QApplication::desktop()->height() )
-      menu->popup(QPoint( g.x(), g.y() - menu->height()));
-    else
-      menu->popup(QPoint( g.x() + g.width(), g.y() + g.height()));
-  }
+    menu->popup(QCursor::pos());
 }
 
 
@@ -180,7 +172,7 @@ void TopLevel::timerEvent(QTimerEvent *)
       if (beeping)
         kapp->beep();
       if (!action.isEmpty())
-        system(action);
+        system(QFile::encodeName(action));
       if (popping)
         KMessageBox::information(0, i18n("The tea is now ready!"));
 
