@@ -11,13 +11,12 @@
 #define _TOPLEVEL_H_
 
 #include <kapp.h>
-#include <ktmainwindow.h>
 #include <qpopmenu.h>
 #include <qtimer.h>
 #include <qpixmap.h>
 #include <qstringlist.h>
 
-class TopLevel : public KTMainWindow
+class TopLevel : public QWidget
 {
   Q_OBJECT
 
@@ -37,14 +36,14 @@ private slots:
   void teaSelected(int index);
   void start();
   void config();
-    
+
 private:
 
   bool running, ready, frame1;
-  
+
   QStringList teas, times;
-  int seconds, teatime;
-  
+  int seconds, teatime, current_tea;
+
   QPopupMenu *menu;
   QPixmap *mugPixmap, *bagPixmap, *tea1Pixmap, *tea2Pixmap;
 
