@@ -11,7 +11,7 @@
 const int ID_LOCALTIME = 1;
 
 
-class TopLevel : public KTMainWindow
+class TopLevel : public KMainWindow
 {
   Q_OBJECT;
   
@@ -28,8 +28,6 @@ protected:
 
 private:
 
-  KStatusBar *statusbar;
-
   void setupStatusBar();
   
   World *world;
