@@ -4,14 +4,12 @@
 
 #include <qwidget.h>
 #include <qpixmap.h>
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
 #include <qlist.h>
 #include <qtooltip.h>
 #include <time.h>
 
 
-const int GREENWICH = 235;
-
 class TimeTip : public QToolTip
 {
 public:
@@ -29,7 +27,7 @@ class Flag
 {
 public:
 
-  int x, y;
+  double x, y;
   int color;
   QString note;
     
@@ -42,6 +40,7 @@ class World : public QWidget
 
 public:
 
+  World();
   World(QWidget *parent);
   ~World();
   
@@ -50,7 +49,13 @@ public:
   QString &getTip(const QPoint &pos);
 
   static time_t offset;
-    
+
+  void loadMap(QString name);
+  void loadFlags();  
+
+  void dumpMap(QString fname, QSize size);
+
+
 protected:
 
   virtual void paintEvent(QPaintEvent *event);
@@ -58,7 +63,6 @@ protected:
 
   void updateMap();
 
-  void loadFlags();  
   void drawFlags();
   void appendFlag(int x, int y, int c);
   void saveFlags();
@@ -93,7 +97,8 @@ private slots:
   void annotateFlag();
   void illuminateMap();
   void toggleSimulation();
-        
+  void selectMap();
+
 };
 
 #endif
